Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Registerer ¶
type Registerer interface {
// Register Processor registers event processors for a certain type of PU
RegisterProcessor(puType common.PUType, p processor.Processor) error
GetHandler(puType common.PUType, e common.Event) (common.EventHandler, error)
}
Registerer inteface allows event processors to register themselves with the event server.
Click to show internal directories.
Click to hide internal directories.